# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file './kuafu/resources/ui_library.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_librarywidget(object):
    def setupUi(self, librarywidget):
        librarywidget.setObjectName("librarywidget")
        librarywidget.resize(1115, 701)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(librarywidget)
        self.horizontalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_4.setSpacing(0)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.splitter = QtWidgets.QSplitter(librarywidget)
        self.splitter.setOrientation(QtCore.Qt.Horizontal)
        self.splitter.setObjectName("splitter")
        self.widget = QtWidgets.QWidget(self.splitter)
        self.widget.setMaximumSize(QtCore.QSize(600, 16777215))
        self.widget.setObjectName("widget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.widget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.pushButton_open = QtWidgets.QPushButton(self.widget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_open.sizePolicy().hasHeightForWidth())
        self.pushButton_open.setSizePolicy(sizePolicy)
        self.pushButton_open.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/document-open.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_open.setIcon(icon)
        self.pushButton_open.setFlat(True)
        self.pushButton_open.setObjectName("pushButton_open")
        self.horizontalLayout_2.addWidget(self.pushButton_open)
        self.pushButton_save_all = QtWidgets.QPushButton(self.widget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_save_all.sizePolicy().hasHeightForWidth())
        self.pushButton_save_all.setSizePolicy(sizePolicy)
        self.pushButton_save_all.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/document-save.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_save_all.setIcon(icon1)
        self.pushButton_save_all.setFlat(True)
        self.pushButton_save_all.setObjectName("pushButton_save_all")
        self.horizontalLayout_2.addWidget(self.pushButton_save_all)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.fileview = QtWidgets.QTreeView(self.widget)
        self.fileview.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.fileview.setObjectName("fileview")
        self.verticalLayout.addWidget(self.fileview)
        self.widget1 = QtWidgets.QWidget(self.splitter)
        self.widget1.setObjectName("widget1")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.widget1)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setSpacing(0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSpacing(0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.pushButton_prev = QtWidgets.QPushButton(self.widget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_prev.sizePolicy().hasHeightForWidth())
        self.pushButton_prev.setSizePolicy(sizePolicy)
        self.pushButton_prev.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/icons/go-previous.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_prev.setIcon(icon2)
        self.pushButton_prev.setFlat(True)
        self.pushButton_prev.setObjectName("pushButton_prev")
        self.horizontalLayout.addWidget(self.pushButton_prev)
        self.pushButton_next = QtWidgets.QPushButton(self.widget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_next.sizePolicy().hasHeightForWidth())
        self.pushButton_next.setSizePolicy(sizePolicy)
        self.pushButton_next.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/icons/go-next.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_next.setIcon(icon3)
        self.pushButton_next.setFlat(True)
        self.pushButton_next.setObjectName("pushButton_next")
        self.horizontalLayout.addWidget(self.pushButton_next)
        self.line = QtWidgets.QFrame(self.widget1)
        self.line.setMaximumSize(QtCore.QSize(16777215, 28))
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout.addWidget(self.line)
        self.pushButton_zoomIn = QtWidgets.QPushButton(self.widget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_zoomIn.sizePolicy().hasHeightForWidth())
        self.pushButton_zoomIn.setSizePolicy(sizePolicy)
        self.pushButton_zoomIn.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/icons/zoom-in.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_zoomIn.setIcon(icon4)
        self.pushButton_zoomIn.setFlat(True)
        self.pushButton_zoomIn.setObjectName("pushButton_zoomIn")
        self.horizontalLayout.addWidget(self.pushButton_zoomIn)
        self.pushButton_zoomOut = QtWidgets.QPushButton(self.widget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_zoomOut.sizePolicy().hasHeightForWidth())
        self.pushButton_zoomOut.setSizePolicy(sizePolicy)
        self.pushButton_zoomOut.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/icons/zoom-out.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_zoomOut.setIcon(icon5)
        self.pushButton_zoomOut.setFlat(True)
        self.pushButton_zoomOut.setObjectName("pushButton_zoomOut")
        self.horizontalLayout.addWidget(self.pushButton_zoomOut)
        self.pushButton_zoomFitWidth = QtWidgets.QPushButton(self.widget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_zoomFitWidth.sizePolicy().hasHeightForWidth())
        self.pushButton_zoomFitWidth.setSizePolicy(sizePolicy)
        self.pushButton_zoomFitWidth.setText("")
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/icons/zoom-fit-width.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_zoomFitWidth.setIcon(icon6)
        self.pushButton_zoomFitWidth.setCheckable(True)
        self.pushButton_zoomFitWidth.setFlat(True)
        self.pushButton_zoomFitWidth.setObjectName("pushButton_zoomFitWidth")
        self.horizontalLayout.addWidget(self.pushButton_zoomFitWidth)
        self.line_2 = QtWidgets.QFrame(self.widget1)
        self.line_2.setMaximumSize(QtCore.QSize(16777215, 28))
        self.line_2.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.horizontalLayout.addWidget(self.line_2)
        self.pushButton_oneColumn = QtWidgets.QPushButton(self.widget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_oneColumn.sizePolicy().hasHeightForWidth())
        self.pushButton_oneColumn.setSizePolicy(sizePolicy)
        self.pushButton_oneColumn.setText("")
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/icons/snap-page.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_oneColumn.setIcon(icon7)
        self.pushButton_oneColumn.setCheckable(True)
        self.pushButton_oneColumn.setFlat(True)
        self.pushButton_oneColumn.setObjectName("pushButton_oneColumn")
        self.horizontalLayout.addWidget(self.pushButton_oneColumn)
        self.pushButton_twoColumn = QtWidgets.QPushButton(self.widget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_twoColumn.sizePolicy().hasHeightForWidth())
        self.pushButton_twoColumn.setSizePolicy(sizePolicy)
        self.pushButton_twoColumn.setText("")
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/icons/view-pages-facing.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_twoColumn.setIcon(icon8)
        self.pushButton_twoColumn.setCheckable(True)
        self.pushButton_twoColumn.setFlat(True)
        self.pushButton_twoColumn.setObjectName("pushButton_twoColumn")
        self.horizontalLayout.addWidget(self.pushButton_twoColumn)
        self.pushButton_fourColumn = QtWidgets.QPushButton(self.widget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_fourColumn.sizePolicy().hasHeightForWidth())
        self.pushButton_fourColumn.setSizePolicy(sizePolicy)
        self.pushButton_fourColumn.setText("")
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/icons/view-pages-overview.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_fourColumn.setIcon(icon9)
        self.pushButton_fourColumn.setCheckable(True)
        self.pushButton_fourColumn.setFlat(True)
        self.pushButton_fourColumn.setObjectName("pushButton_fourColumn")
        self.horizontalLayout.addWidget(self.pushButton_fourColumn)
        self.pushButton_emptyPage = QtWidgets.QPushButton(self.widget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_emptyPage.sizePolicy().hasHeightForWidth())
        self.pushButton_emptyPage.setSizePolicy(sizePolicy)
        self.pushButton_emptyPage.setText("")
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/icons/page-simple.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_emptyPage.setIcon(icon10)
        self.pushButton_emptyPage.setCheckable(True)
        self.pushButton_emptyPage.setFlat(True)
        self.pushButton_emptyPage.setObjectName("pushButton_emptyPage")
        self.horizontalLayout.addWidget(self.pushButton_emptyPage)
        self.line_3 = QtWidgets.QFrame(self.widget1)
        self.line_3.setMaximumSize(QtCore.QSize(16777215, 28))
        self.line_3.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.horizontalLayout.addWidget(self.line_3)
        self.tocButton_1 = TocPushButton(self.widget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tocButton_1.sizePolicy().hasHeightForWidth())
        self.tocButton_1.setSizePolicy(sizePolicy)
        self.tocButton_1.setMinimumSize(QtCore.QSize(0, 0))
        self.tocButton_1.setMaximumSize(QtCore.QSize(16777215, 32))
        self.tocButton_1.setFocusPolicy(QtCore.Qt.NoFocus)
        self.tocButton_1.setStyleSheet("text-align:left")
        self.tocButton_1.setFlat(True)
        self.tocButton_1.setObjectName("tocButton_1")
        self.horizontalLayout.addWidget(self.tocButton_1)
        self.lineEdit_pageNo = PageNoLineEdit(self.widget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEdit_pageNo.sizePolicy().hasHeightForWidth())
        self.lineEdit_pageNo.setSizePolicy(sizePolicy)
        self.lineEdit_pageNo.setMaximumSize(QtCore.QSize(52, 32))
        self.lineEdit_pageNo.setStyleSheet("")
        self.lineEdit_pageNo.setObjectName("lineEdit_pageNo")
        self.horizontalLayout.addWidget(self.lineEdit_pageNo)
        self.label_of = QtWidgets.QLabel(self.widget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_of.sizePolicy().hasHeightForWidth())
        self.label_of.setSizePolicy(sizePolicy)
        self.label_of.setObjectName("label_of")
        self.horizontalLayout.addWidget(self.label_of)
        self.label_pageCount = QtWidgets.QLabel(self.widget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_pageCount.sizePolicy().hasHeightForWidth())
        self.label_pageCount.setSizePolicy(sizePolicy)
        self.label_pageCount.setMinimumSize(QtCore.QSize(48, 0))
        self.label_pageCount.setMaximumSize(QtCore.QSize(48, 32))
        self.label_pageCount.setStyleSheet("")
        self.label_pageCount.setAlignment(QtCore.Qt.AlignCenter)
        self.label_pageCount.setObjectName("label_pageCount")
        self.horizontalLayout.addWidget(self.label_pageCount)
        self.verticalLayout_2.addLayout(self.horizontalLayout)
        self.preview_graphicsview = DocGraphicsView(self.widget1)
        self.preview_graphicsview.setObjectName("preview_graphicsview")
        self.verticalLayout_2.addWidget(self.preview_graphicsview)
        self.widget2 = QtWidgets.QWidget(self.splitter)
        self.widget2.setMinimumSize(QtCore.QSize(150, 0))
        self.widget2.setMaximumSize(QtCore.QSize(400, 16777215))
        self.widget2.setObjectName("widget2")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.widget2)
        self.verticalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_3.setSpacing(0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setSpacing(0)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem1)
        self.lineEdit_find = QtWidgets.QLineEdit(self.widget2)
        self.lineEdit_find.setObjectName("lineEdit_find")
        self.horizontalLayout_3.addWidget(self.lineEdit_find)
        self.verticalLayout_3.addLayout(self.horizontalLayout_3)
        self.thumb_graphicsview = ThumbGraphicsView(self.widget2)
        self.thumb_graphicsview.setMinimumSize(QtCore.QSize(0, 0))
        self.thumb_graphicsview.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.thumb_graphicsview.setObjectName("thumb_graphicsview")
        self.verticalLayout_3.addWidget(self.thumb_graphicsview)
        self.horizontalLayout_4.addWidget(self.splitter)

        self.retranslateUi(librarywidget)
        QtCore.QMetaObject.connectSlotsByName(librarywidget)

    def retranslateUi(self, librarywidget):
        _translate = QtCore.QCoreApplication.translate
        librarywidget.setWindowTitle(_translate("librarywidget", "Form"))
        self.tocButton_1.setText(_translate("librarywidget", " ⯈ "))
        self.label_of.setText(_translate("librarywidget", "  of"))
        self.label_pageCount.setText(_translate("librarywidget", "0 "))
from docgraphicsview import DocGraphicsView
from pagenolineedit import PageNoLineEdit
from thumbgraphicsview import ThumbGraphicsView
from tocpushbutton import TocPushButton
import resources_rc
