# -*- coding: utf-8 -*-

"""
Name = kuafu
Executable Command = kuafu
Package Name = kuafu
Python Module Name = kuafu
Debian Dependency = python3-pyqt5, python3-poppler-qt5

Description = A paper manger
Changes :
0.0.2   fixed :
0.0.1   added :
0.0.10   initial draft version

...........................................................................
|   Copyright (C) 2020-2021 Yinlin Hu <huyinlin@gmail.com>       |
|                                                                          |
|   This program is free software: you can redistribute it and/or modify   |
|   it under the terms of the GNU General Public License as published by   |
|   the Free Software Foundation, either version 3 of the License, or      |
|   (at your option) any later version.                                    |
|                                                                          |
|   This program is distributed in the hope that it will be useful,        |
|   but WITHOUT ANY WARRANTY; without even the implied warranty of         |
|   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
|   GNU General Public License for more details.                           |
|                                                                          |
|   You should have received a copy of the GNU General Public License      |
|   along with this program.  If not, see <http://www.gnu.org/licenses/>.  |
...........................................................................
"""

# TODO:
# There will be duplicated rendering when have multiple requests
# FIXME :

__version__ = '0.0.24'
