# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file './kuafu/resources/ui_main.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_window(object):
    def setupUi(self, window):
        window.setObjectName("window")
        window.resize(905, 722)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/kuafu.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        window.setWindowIcon(icon)
        self.centralwidget = QtWidgets.QWidget(window)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.centraltabwidget = QtWidgets.QTabWidget(self.centralwidget)
        self.centraltabwidget.setTabBarAutoHide(True)
        self.centraltabwidget.setObjectName("centraltabwidget")
        self.verticalLayout_2.addWidget(self.centraltabwidget)
        window.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(window)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 905, 30))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuExport = QtWidgets.QMenu(self.menuFile)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/export.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.menuExport.setIcon(icon1)
        self.menuExport.setObjectName("menuExport")
        self.menuRecentFiles = QtWidgets.QMenu(self.menuFile)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/icons/recents.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.menuRecentFiles.setIcon(icon2)
        self.menuRecentFiles.setObjectName("menuRecentFiles")
        self.menuNavigate = QtWidgets.QMenu(self.menubar)
        self.menuNavigate.setObjectName("menuNavigate")
        self.menuView = QtWidgets.QMenu(self.menubar)
        self.menuView.setObjectName("menuView")
        window.setMenuBar(self.menubar)
        self.statusBar = QtWidgets.QStatusBar(window)
        self.statusBar.setObjectName("statusBar")
        window.setStatusBar(self.statusBar)
        self.openFileAction = QtWidgets.QAction(window)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/icons/document-open.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.openFileAction.setIcon(icon3)
        self.openFileAction.setObjectName("openFileAction")
        self.quitAction = QtWidgets.QAction(window)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/icons/im-ban-kick-user.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.quitAction.setIcon(icon4)
        self.quitAction.setObjectName("quitAction")
        self.zoominAction = QtWidgets.QAction(window)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/icons/zoom-in.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.zoominAction.setIcon(icon5)
        self.zoominAction.setObjectName("zoominAction")
        self.zoomoutAction = QtWidgets.QAction(window)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/icons/zoom-out.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.zoomoutAction.setIcon(icon6)
        self.zoomoutAction.setObjectName("zoomoutAction")
        self.prevPageAction = QtWidgets.QAction(window)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/icons/go-up.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.prevPageAction.setIcon(icon7)
        self.prevPageAction.setObjectName("prevPageAction")
        self.nextPageAction = QtWidgets.QAction(window)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/icons/go-down.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.nextPageAction.setIcon(icon8)
        self.nextPageAction.setObjectName("nextPageAction")
        self.undoJumpAction = QtWidgets.QAction(window)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/icons/go-previous.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.undoJumpAction.setIcon(icon9)
        self.undoJumpAction.setObjectName("undoJumpAction")
        self.saveFileAction = QtWidgets.QAction(window)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/icons/document-save.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.saveFileAction.setIcon(icon10)
        self.saveFileAction.setObjectName("saveFileAction")
        self.toPSAction = QtWidgets.QAction(window)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/icons/adobe.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.toPSAction.setIcon(icon11)
        self.toPSAction.setObjectName("toPSAction")
        self.docInfoAction = QtWidgets.QAction(window)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(":/icons/info.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.docInfoAction.setIcon(icon12)
        self.docInfoAction.setObjectName("docInfoAction")
        self.pageToImageAction = QtWidgets.QAction(window)
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(":/icons/image.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pageToImageAction.setIcon(icon13)
        self.pageToImageAction.setObjectName("pageToImageAction")
        self.printAction = QtWidgets.QAction(window)
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap(":/icons/document-print.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.printAction.setIcon(icon14)
        self.printAction.setObjectName("printAction")
        self.pageCountAction = QtWidgets.QAction(window)
        self.pageCountAction.setObjectName("pageCountAction")
        self.redoJumpAction = QtWidgets.QAction(window)
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap(":/icons/go-next.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.redoJumpAction.setIcon(icon15)
        self.redoJumpAction.setObjectName("redoJumpAction")
        self.zoomFitwidthAction = QtWidgets.QAction(window)
        self.zoomFitwidthAction.setCheckable(True)
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap(":/icons/zoom-fit-width.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.zoomFitwidthAction.setIcon(icon16)
        self.zoomFitwidthAction.setObjectName("zoomFitwidthAction")
        self.undoModificationAction = QtWidgets.QAction(window)
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(":/icons/edit-undo.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.undoModificationAction.setIcon(icon17)
        self.undoModificationAction.setObjectName("undoModificationAction")
        self.redoModificationAction = QtWidgets.QAction(window)
        icon18 = QtGui.QIcon()
        icon18.addPixmap(QtGui.QPixmap(":/icons/edit-redo.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.redoModificationAction.setIcon(icon18)
        self.redoModificationAction.setObjectName("redoModificationAction")
        self.actionFind = QtWidgets.QAction(window)
        icon19 = QtGui.QIcon()
        icon19.addPixmap(QtGui.QPixmap(":/icons/edit-find.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionFind.setIcon(icon19)
        self.actionFind.setObjectName("actionFind")
        self.actionViewInOneColumn = QtWidgets.QAction(window)
        self.actionViewInOneColumn.setCheckable(True)
        icon20 = QtGui.QIcon()
        icon20.addPixmap(QtGui.QPixmap(":/icons/snap-page.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionViewInOneColumn.setIcon(icon20)
        self.actionViewInOneColumn.setObjectName("actionViewInOneColumn")
        self.actionViewInTwoColumns = QtWidgets.QAction(window)
        self.actionViewInTwoColumns.setCheckable(True)
        icon21 = QtGui.QIcon()
        icon21.addPixmap(QtGui.QPixmap(":/icons/view-pages-facing.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionViewInTwoColumns.setIcon(icon21)
        self.actionViewInTwoColumns.setObjectName("actionViewInTwoColumns")
        self.actionPrecedingEmptyPage = QtWidgets.QAction(window)
        self.actionPrecedingEmptyPage.setCheckable(True)
        icon22 = QtGui.QIcon()
        icon22.addPixmap(QtGui.QPixmap(":/icons/page-simple.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionPrecedingEmptyPage.setIcon(icon22)
        self.actionPrecedingEmptyPage.setObjectName("actionPrecedingEmptyPage")
        self.menuExport.addAction(self.pageToImageAction)
        self.menuExport.addAction(self.toPSAction)
        self.menuFile.addAction(self.openFileAction)
        self.menuFile.addAction(self.menuRecentFiles.menuAction())
        self.menuFile.addAction(self.menuExport.menuAction())
        self.menuFile.addAction(self.printAction)
        self.menuFile.addAction(self.docInfoAction)
        self.menuFile.addAction(self.quitAction)
        self.menuView.addAction(self.zoominAction)
        self.menuView.addAction(self.zoomoutAction)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuView.menuAction())
        self.menubar.addAction(self.menuNavigate.menuAction())

        self.retranslateUi(window)
        QtCore.QMetaObject.connectSlotsByName(window)

    def retranslateUi(self, window):
        _translate = QtCore.QCoreApplication.translate
        window.setWindowTitle(_translate("window", "kuafu"))
        self.menuFile.setTitle(_translate("window", "&File"))
        self.menuExport.setTitle(_translate("window", "Export"))
        self.menuRecentFiles.setTitle(_translate("window", "Recent Files"))
        self.menuNavigate.setTitle(_translate("window", "Help"))
        self.menuView.setTitle(_translate("window", "&View"))
        self.openFileAction.setText(_translate("window", "Open"))
        self.openFileAction.setShortcut(_translate("window", "Ctrl+O"))
        self.quitAction.setText(_translate("window", "Quit"))
        self.quitAction.setShortcut(_translate("window", "Ctrl+Q"))
        self.zoominAction.setText(_translate("window", "Zoom In"))
        self.zoominAction.setShortcut(_translate("window", "Ctrl++"))
        self.zoomoutAction.setText(_translate("window", "Zoom Out"))
        self.zoomoutAction.setShortcut(_translate("window", "Ctrl+-"))
        self.prevPageAction.setText(_translate("window", "Prev Page"))
        self.prevPageAction.setShortcut(_translate("window", "Left"))
        self.nextPageAction.setText(_translate("window", "Next Page"))
        self.nextPageAction.setShortcut(_translate("window", "Right"))
        self.undoJumpAction.setText(_translate("window", "Undo Jump"))
        self.undoJumpAction.setToolTip(_translate("window", "Undo Jump"))
        self.undoJumpAction.setShortcut(_translate("window", "Shift+Backspace"))
        self.saveFileAction.setText(_translate("window", "Save"))
        self.saveFileAction.setShortcut(_translate("window", "Ctrl+S"))
        self.toPSAction.setText(_translate("window", "to PostScript"))
        self.docInfoAction.setText(_translate("window", "Document Info"))
        self.pageToImageAction.setText(_translate("window", "Page to Image"))
        self.printAction.setText(_translate("window", "Print"))
        self.printAction.setToolTip(_translate("window", "Print with QuikPrint"))
        self.printAction.setShortcut(_translate("window", "Ctrl+P"))
        self.pageCountAction.setText(_translate("window", "0"))
        self.pageCountAction.setShortcut(_translate("window", "Ctrl+G"))
        self.redoJumpAction.setText(_translate("window", "Redo Jump"))
        self.redoJumpAction.setToolTip(_translate("window", "Redo Jump"))
        self.redoJumpAction.setShortcut(_translate("window", "Shift+Backspace"))
        self.zoomFitwidthAction.setText(_translate("window", "Zoom Fit Width"))
        self.zoomFitwidthAction.setToolTip(_translate("window", "Zoom Fit Width"))
        self.undoModificationAction.setText(_translate("window", "Undo Modification"))
        self.undoModificationAction.setToolTip(_translate("window", "Undo Modification"))
        self.undoModificationAction.setShortcut(_translate("window", "Ctrl+Z"))
        self.redoModificationAction.setText(_translate("window", "Redo Modification"))
        self.redoModificationAction.setToolTip(_translate("window", "Redo Modification"))
        self.redoModificationAction.setShortcut(_translate("window", "Ctrl+Y"))
        self.actionFind.setText(_translate("window", "Find"))
        self.actionFind.setToolTip(_translate("window", "Find"))
        self.actionFind.setShortcut(_translate("window", "Ctrl+F"))
        self.actionViewInOneColumn.setText(_translate("window", "View In One Column"))
        self.actionViewInOneColumn.setToolTip(_translate("window", "View In One Column"))
        self.actionViewInTwoColumns.setText(_translate("window", "View In Two Columns"))
        self.actionViewInTwoColumns.setToolTip(_translate("window", "View In Two Columns"))
        self.actionPrecedingEmptyPage.setText(_translate("window", "Preceding Empty Page"))
        self.actionPrecedingEmptyPage.setToolTip(_translate("window", "Preceding Empty Page"))
import resources_rc
